@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 # shortcuts
 use constant os_freebsd  => (os => 'freebsd');
@@ -569,7 +569,7 @@ sub mapping {
 
      [cpanmod => 'Geo::Proj4',
       [os_freebsd,
-       [package => 'libproj4']],
+       [package => ['libproj4', 'proj']]],
       [like_debian,
        [package => ['libproj-dev', 'proj-bin']]],
       [os_darwin,
@@ -822,7 +822,7 @@ sub mapping {
 
      [cpanmod => 'Imager',
       [os_freebsd,
-       [package => [qw(freetype2 giflib-nox11 png tiff jpeg)]]],
+       [package => [qw(freetype2 giflib png tiff), 'jpeg | jpeg-turbo']]], # in former days giflib-nox11 had to be specified
       [like_debian,
        [linuxdistrocodename => 'wheezy',
 	[package => [qw(libfreetype6-dev libgif-dev libpng12-dev libjpeg-dev), 'libtiff5-dev | libtiff4-dev']]],
@@ -843,7 +843,8 @@ sub mapping {
       # XXX TBD how's the state in Ubuntu?
      ],
 
-     [cpanmod => 'Inline::Java',
+     # modules just needing java and nothing else:
+     [cpanmod => ['Inline::Java', 'Bio::AssemblyImprovement', 'DBD::JDBC'],
       [os_freebsd,
        [package => 'openjdk8']],
       [like_debian,
@@ -1500,6 +1501,13 @@ sub mapping {
      [cpanmod => 'Video::FFmpeg',
       [package => 'ffmpeg']], # on Debian only found in backports or www.deb-multimedia.org; still does not build because avformat.h is not available
 
+     [cpanmod => 'WordNet::QueryData',
+      [os_freebsd,
+       [package => 'wordnet']],
+      [like_debian,
+       [package => 'wordnet-base']],
+     ],
+
      [cpanmod => 'WWW::Bootstrap',
       [os_freebsd,
        [package => 'npm']],
